@@ -18,6 +18,7 @@
 #include <ucommon/export.h>
 #include <sipwitch/uri.h>
 #include <sipwitch/service.h>
+#include <sipwitch/modules.h>
 
 #ifdef  HAVE_RESOLV_H
 extern "C" {
@@ -136,6 +137,18 @@ void srv::set(const char *uri)
         hint.ai_flags |= AI_NUMERICSERV;
 #endif
 
+    linked_pointer<modules::generic> cb = service::getGenerics();
+    while(is(cb)) {
+        srvlist = cb->resolve(uri, &hint);
+        if(srvlist) {
+            count = 1;
+            entry = (struct sockaddr *)&srvlist[0].addr;
+            pri = srvlist[0].priority;
+            return;
+        }
+        cb.next();
+    }
+
 #ifdef  HAVE_RESOLV_H
     int result;
     HEADER *hp;
@@ -169,7 +182,7 @@ void srv::set(const char *uri)
     if(!acount)
         goto nosrv;
 
-    srvlist = new srvaddrinfo[acount];
+    srvlist = new srv::address[acount];
     while(qcount-- > 0 && cp < ep) {
         result = dn_expand(mp, ep, cp, hbuf, sizeof(hbuf));
         if(result < 0)
@@ -219,7 +232,7 @@ void srv::set(const char *uri)
 
         if(sp) {
             uint16_t rand;
-            srvaddrinfo *current = NULL;
+            srv::address *current = NULL;
 
             Random::fill((unsigned char *)&rand, sizeof(rand));
             rand &= 0x7fff;
@@ -288,7 +301,7 @@ struct sockaddr *srv::next(void)
 {
 #ifdef  HAVE_RESOLV_H
     unsigned index = 0;
-    srvaddrinfo *node = NULL, *np = NULL;
+    srv::address *node = NULL, *np = NULL;
     ++pri;
     while(index < count) {
         np = &srvlist[index++];
