@@ -124,101 +124,6 @@ unsigned short uri::portid(const char *uri)
         return 0;
 }
 
-bool uri::rewrite(const char *sipuri, char *buffer, size_t size)
-{
-    const char *schema = "sip:";
-    size_t prefix = 4;
-    const char *name = strchr(sipuri, '@');
-    char *ep;
-
-    if(String::equal(sipuri, "sips:", 5)) {
-        sipuri += 5;
-        prefix = 5;
-        schema = "sips:";
-    }
-    if(String::equal(sipuri, "sip:", 4))
-        sipuri += 4;
-
-    String::set(buffer, size, schema);
-    buffer += prefix;
-    size -= prefix;
-
-    if(name) {
-        sipuri = name + 1;
-        String::set(buffer, size, sipuri);
-        ep = strchr(buffer, '@');
-        if(ep) {
-            *(++ep) = 0;
-            prefix = strlen(buffer);
-            size -= prefix;
-            buffer += prefix;
-        }
-    }
-    return resolve(sipuri, buffer, size);
-}
-
-bool uri::resolve(const char *sipuri, char *buffer, size_t size)
-{
-    assert(sipuri != NULL);
-    assert(buffer != NULL);
-    assert(size > 0);
-
-    const char *uriname;
-    char *cp;
-    unsigned port = 0;
-    struct sockaddr *address;
-
-    if(String::equal(sipuri, "sips:", 5))
-        sipuri += 5;
-    if(String::equal(sipuri, "sip:", 4))
-        sipuri += 4;
-
-    uriname = strchr(sipuri, '@');
-    if(uriname)
-        sipuri = ++uriname;
-
-    if(*sipuri == '[') {
-        String::set(buffer, size, ++sipuri);
-        cp = strchr(buffer, ']');
-        if(cp)
-            *(cp++) = 0;
-        if(cp && *cp == ':')
-            ++cp;
-        if(cp)
-            port = atoi(cp);
-    }
-    else {
-        String::set(buffer, size, sipuri);
-        cp = strchr(buffer, ':');
-        if(cp) {
-            *(cp++) = 0;
-            port = atoi(cp);
-        }
-    }
-    if(Socket::is_numeric(buffer)) {
-        if(!port)
-            port = 5060;
-    }
-    else {
-        Socket::address resolver;
-        resolver.set(buffer, port);
-        address = resolver.getAddr();
-        if(address) {
-            Socket::query(address, buffer, size);
-            port = Socket::service(address);
-            if(!port)
-                port = 5060;
-        }
-        else
-            return false;
-    }
-
-    size_t len = strlen(buffer);
-    if(port)
-        snprintf(buffer + len, size - len, ":%u", port);
-    return true;
-}
-
 void uri::publish(const char *uri, char *buf, const char *user, size_t size)
 {
     assert(uri != NULL);
